abacusai.code_edit_response — AbacusAI documentation

# abacusai.code_edit_response

## Classes

`CodeEditResponse` | A code edit response from an LLM

## Module Contents

class abacusai.code_edit_response.CodeEditResponse(client, codeChanges=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  A code edit response from an LLM

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - codeChanges (list) – The code changes to be applied.

  code_changes
  deprecated_keys
  __repr__()
  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict